==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/registry/content/block/RDWoodBlocks.java <==
package cc.thonly.reverie_dreams.registry.content.block;

import cc.thonly.reverie_dreams.block.base.FertilizableFlowerBlock;
import cc.thonly.reverie_dreams.block.base.FruitLeavesBlock;
import cc.thonly.reverie_dreams.block.creator.WoodCreator;
import cc.thonly.reverie_dreams.registry.content.item.RDIngredientItems;
import cc.thonly.reverie_dreams.world.sapling.SaplingGeneratorInit;
import net.minecraft.class_1294;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2356;
import net.minecraft.class_4970;

public class RDWoodBlocks {
    public static final WoodCreator SPIRITUAL = WoodCreator.create("spiritual", SaplingGeneratorInit.SPIRITUAL_TREE).build();
    public static final WoodCreator LEMON = WoodCreator.create(
            "lemon", SaplingGeneratorInit.LEMON_TREE).build();
    public static final class_2248 LEMON_FRUIT_LEAVES = RDBlocks.registerSimpleBlock(
            "lemon_fruit_leaves",
            (settings) -> new FruitLeavesBlock(RDIngredientItems.LEMON, LEMON.leaves(), settings), class_4970.class_2251.method_9630(class_2246.field_10503));
    public static final WoodCreator GINKGO = WoodCreator.create(
            "ginkgo", SaplingGeneratorInit.GINKGO_TREE).build();
    public static final class_2248 GINKGO_FRUIT_LEAVES = RDBlocks.registerSimpleBlock(
            "ginkgo_fruit_leaves",
            (settings) -> new FruitLeavesBlock(RDIngredientItems.GINKGO, GINKGO.leaves(), settings), class_4970.class_2251.method_9630(class_2246.field_10503));
    public static final WoodCreator PEACH = WoodCreator.create(
            "peach", SaplingGeneratorInit.PEACH_TREE).build();
    public static final class_2248 PEACH_FRUIT_LEAVES = RDBlocks.registerSimpleBlock(
            "peach_fruit_leaves",
            (settings) -> new FruitLeavesBlock(RDIngredientItems.PEACH, PEACH.leaves(), settings), class_4970.class_2251.method_9630(class_2246.field_10503));
    public static final class_2248 UDUMBARA_FLOWER = RDBlocks.registerSimpleBlock(
            "udumbara_flower",
            (settings) -> new FertilizableFlowerBlock(class_1294.field_5924, 3f, settings), RDPlantBlocks.createPlantSettings());
    public static final class_2248 TREMELLA = RDBlocks.registerSimpleBlock(
            "tremella",
            (settings) -> new class_2356(class_1294.field_5924, 3f, settings), RDPlantBlocks.createPlantSettings());
    public static void registerBlocks() {

    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/registry/content/block/RDWoodBlocks.java <==
package cc.thonly.reverie_dreams.registry.content.block;

import cc.thonly.reverie_dreams.block.base.FertilizableFlowerBlock;
import cc.thonly.reverie_dreams.block.base.FruitLeavesBlock;
import cc.thonly.reverie_dreams.block.creator.WoodCreator;
import cc.thonly.reverie_dreams.registry.content.item.RDIngredientItems;
import cc.thonly.reverie_dreams.world.sapling.SaplingGeneratorInit;
import net.fabricmc.fabric.api.registry.StrippableBlockRegistry;
import net.minecraft.class_1294;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2356;
import net.minecraft.class_2465;
import net.minecraft.class_4970;

public class RDWoodBlocks {
    public static final WoodCreator SPIRITUAL = WoodCreator.create("spiritual", SaplingGeneratorInit.SPIRITUAL_TREE).build();
    public static final class_2248 BLESSED_SPIRITUAL_LOG = RDBlocks.registerBlock("blessed_spiritual_log", class_2465::new, class_2246.field_10431.method_54095());
    public static final WoodCreator LEMON = WoodCreator.create(
            "lemon", SaplingGeneratorInit.LEMON_TREE).build();
    public static final class_2248 LEMON_FRUIT_LEAVES = RDBlocks.registerSimpleBlock(
            "lemon_fruit_leaves",
            (settings) -> new FruitLeavesBlock(RDIngredientItems.LEMON, LEMON.leaves(), settings), class_4970.class_2251.method_9630(class_2246.field_10503));
    public static final WoodCreator GINKGO = WoodCreator.create(
            "ginkgo", SaplingGeneratorInit.GINKGO_TREE).build();
    public static final class_2248 GINKGO_FRUIT_LEAVES = RDBlocks.registerSimpleBlock(
            "ginkgo_fruit_leaves",
            (settings) -> new FruitLeavesBlock(RDIngredientItems.GINKGO, GINKGO.leaves(), settings), class_4970.class_2251.method_9630(class_2246.field_10503));
    public static final WoodCreator PEACH = WoodCreator.create(
            "peach", SaplingGeneratorInit.PEACH_TREE).build();
    public static final class_2248 PEACH_FRUIT_LEAVES = RDBlocks.registerSimpleBlock(
            "peach_fruit_leaves",
            (settings) -> new FruitLeavesBlock(RDIngredientItems.PEACH, PEACH.leaves(), settings), class_4970.class_2251.method_9630(class_2246.field_10503));
    public static final class_2248 UDUMBARA_FLOWER = RDBlocks.registerSimpleBlock(
            "udumbara_flower",
            (settings) -> new FertilizableFlowerBlock(class_1294.field_5924, 3f, settings), RDPlantBlocks.createPlantSettings());
    public static final class_2248 TREMELLA = RDBlocks.registerSimpleBlock(
            "tremella",
            (settings) -> new class_2356(class_1294.field_5924, 3f, settings), RDPlantBlocks.createPlantSettings());
    public static void registerBlocks() {
        StrippableBlockRegistry.register(BLESSED_SPIRITUAL_LOG, SPIRITUAL.strippedLog());

    }
}
